Fit a linear model via the GAGA algorithm using cpp.
rcpp_lm_gaga(
X,
y,
s_alpha,
s_itrNum,
s_thresh,
s_QR_flag,
s_flag,
s_lamda_0,
s_fix_sigma,
s_sigm2_0,
s_fdiag,
s_frp
)Coefficient vector
Input matrix, of dimension nobs*nvars; each row is an observation.
If the intercept term needs to be considered in the estimation process, then the first column of X must be all 1s.
Quantitative response N*1 matrix.
Hyperparameter. The suggested value for alpha is 2 or 3.
The number of iteration steps. In general, 20 steps are enough.
Convergence threshold for beta Change, if max(abs(beta-beta_old))<threshold, return.
It identifies whether to use QR decomposition to speed up the algorithm.
It identifies whether to make model selection. The default is TRUE.
The initial value of the regularization parameter for ridge regression.
It identifies whether to update the variance estimate of the Gaussian noise or not.
The initial variance of the Gaussian noise.
It identifies whether to use diag Approximation to speed up the algorithm.
Pre-processing by OMP method to reduce the number of parameters